@@ -7,45 +7,18 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '0.42';
+our $VERSION = '0.43';
 
 use Moose;
 
-with 'Dist::Zilla::Role::BeforeBuild', 'Dist::Zilla::Role::AfterBuild';
-
-my $weaver_ini = <<'EOF';
-[@CorePrep]
-
-[Name]
-[Version]
-
-[Region  / prelude]
-
-[Generic / SYNOPSIS]
-[Generic / DESCRIPTION]
-
-[Leftovers]
-
-[Region  / postlude]
-
-[Authors]
-[Contributors]
-[Legal]
-EOF
+with 'Dist::Zilla::Role::BeforeBuild';
 
 my $mailmap = <<'EOF';
 Dave Rolsky <autarch@urth.org> <devnull@localhost>
 EOF
 
 my %files = (
-    'weaver.ini' => $weaver_ini,
-    '.mailmap'   => $mailmap,
-);
-
-has _files_written => (
-    is      => 'ro',
-    isa     => 'ArrayRef',
-    default => sub { [] },
+    '.mailmap' => $mailmap,
 );
 
 # These files need to actually exist on disk for the Pod::Weaver plugin to see
@@ -60,46 +33,45 @@ sub before_build {
         print {$fh} $files{$file}
             or die "Cannot write to $files{$file}: $!";
         close $fh;
-
-        push @{ $self->_files_written() }, $file;
     }
 
     return;
 }
 
-sub after_build {
-    my $self = shift;
-
-    unlink $_ for @{ $self->_files_written() };
-
-    return;
-}
-
 __PACKAGE__->meta->make_immutable;
 
 1;
 
-# ABSTRACT: Creates a weaver.ini and .mailmap to populate Contributors in docs
+# ABSTRACT: Creates a .mailmap to populate Contributors in docs
 
 __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-Dist::Zilla::Plugin::DROLSKY::Contributors - Creates a weaver.ini and .mailmap to populate Contributors in docs
+Dist::Zilla::Plugin::DROLSKY::Contributors - Creates a .mailmap to populate Contributors in docs
 
 =head1 VERSION
 
-version 0.42
+version 0.43
 
 =for Pod::Coverage .*
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-PluginBundle-DROLSKY>
+(or L<bug-dist-zilla-pluginbundle-drolsky@rt.cpan.org|mailto:bug-dist-zilla-pluginbundle-drolsky@rt.cpan.org>).
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is Copyright (c) 2016 by Dave Rolsky.
 
