@@ -7,13 +7,10 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '0.42';
+our $VERSION = '0.43';
 
 use Dist::Zilla;
 
-# Not used here, but we want it installed
-use Pod::Weaver::Section::Contributors;
-
 # For the benefit of AutoPrereqs
 use Dist::Zilla::Plugin::Authority;
 use Dist::Zilla::Plugin::AutoPrereqs;
@@ -22,10 +19,12 @@ use Dist::Zilla::Plugin::CPANFile;
 use Dist::Zilla::Plugin::CheckPrereqsIndexed;
 use Dist::Zilla::Plugin::CheckVersionIncrement;
 use Dist::Zilla::Plugin::CopyFilesFromBuild;
+use Dist::Zilla::Plugin::DROLSKY::CheckChangesHasContent;
 use Dist::Zilla::Plugin::DROLSKY::Contributors;
 use Dist::Zilla::Plugin::DROLSKY::License;
 use Dist::Zilla::Plugin::DROLSKY::TidyAll;
 use Dist::Zilla::Plugin::DROLSKY::VersionProvider;
+use Dist::Zilla::Plugin::GenerateFile::FromShareDir;
 use Dist::Zilla::Plugin::Git::Check;
 use Dist::Zilla::Plugin::Git::CheckFor::MergeConflicts;
 use Dist::Zilla::Plugin::Git::Commit;
@@ -44,9 +43,11 @@ use Dist::Zilla::Plugin::MetaResources;
 use Dist::Zilla::Plugin::MojibakeTests;
 use Dist::Zilla::Plugin::NextRelease;
 use Dist::Zilla::Plugin::PodSyntaxTests;
+use Dist::Zilla::Plugin::PPPort;
 use Dist::Zilla::Plugin::PromptIfStale;
 use Dist::Zilla::Plugin::ReadmeAnyFromPod;
 use Dist::Zilla::Plugin::SurgicalPodWeaver;
+use Dist::Zilla::Plugin::Test::CleanNamespaces;
 use Dist::Zilla::Plugin::Test::CPAN::Changes;
 use Dist::Zilla::Plugin::Test::CPAN::Meta::JSON;
 use Dist::Zilla::Plugin::Test::Compile;
@@ -182,9 +183,11 @@ sub _build_plugins {
 
     my %exclude_filename = map { $_ => 1 } qw(
         Build.PL
+        CONTRIBUTING.md
         cpanfile
         LICENSE
         Makefile.PL
+        ppport.h
         README.md
     );
 
@@ -198,12 +201,9 @@ sub _build_plugins {
         }
     }
 
-    my @allow_dirty = (
-        keys %exclude_filename, qw(
-            Changes
-            CONTRIBUTING.md
-            )
-    );
+    my @allow_dirty = ( keys %exclude_filename, 'Changes' );
+
+    my $has_xs = !!( scalar glob('*.xs') );
 
     my @plugins = (
         $self->make_tool,
@@ -222,7 +222,9 @@ sub _build_plugins {
         ],
         [
             CopyFilesFromBuild => {
-                copy => [qw( Build.PL cpanfile LICENSE Makefile.PL )],
+                copy => [
+                    qw( Build.PL cpanfile LICENSE Makefile.PL ppport.h README.md )
+                ],
             },
         ],
         [
@@ -266,29 +268,22 @@ sub _build_plugins {
                 'Perl::Tidy'   => '20140711',
             }
         ],
+
         [
             'PromptIfStale' => {
                 phase             => 'release',
                 check_all_plugins => 1,
                 check_all_prereqs => 1,
                 skip              => [
+                    'Dist::Zilla::Plugin::DROLSKY::CheckChangesHasContent',
                     'Dist::Zilla::Plugin::DROLSKY::Contributors',
+                    'Dist::Zilla::Plugin::DROLSKY::Git::CheckFor::CorrectBranch',
                     'Dist::Zilla::Plugin::DROLSKY::License',
                     'Dist::Zilla::Plugin::DROLSKY::TidyAll',
                     'Dist::Zilla::Plugin::DROLSKY::VersionProvider',
                 ],
             }
         ],
-        [
-            'ReadmeAnyFromPod' => 'README.md in build' => {
-                filename => 'README.md',
-            },
-        ],
-        [
-            'ReadmeAnyFromPod' => 'README.md in root' => {
-                filename => 'README.md',
-            },
-        ],
         [
             'Test::Pod::Coverage::Configurable' => {
                 (
@@ -328,9 +323,17 @@ sub _build_plugins {
             ConfirmRelease
             UploadToCPAN
             ),
+        [
+            'GenerateFile::FromShareDir' => 'generate CONTRIBUTING' => {
+                -dist     => 'Dist-Zilla-PluginBundle-DROLSKY',
+                -filename => 'CONTRIBUTING.md',
+                has_xs    => $has_xs,
+            },
+        ],
         qw(
             CheckPrereqsIndexed
             CPANFile
+            DROLSKY::CheckChangesHasContent
             DROLSKY::Contributors
             DROLSKY::License
             DROLSKY::TidyAll
@@ -342,11 +345,30 @@ sub _build_plugins {
             Meta::Contributors
             MetaConfig
             MetaJSON
-            SurgicalPodWeaver
             ),
+
+        [
+            SurgicalPodWeaver => {
+                config_plugin => '@DROLSKY',
+            },
+        ],
+
+        ( $has_xs ? 'PPPort' : () ),
+
+        # This needs to come after pod weaving
+        [
+            'ReadmeAnyFromPod' => 'README.md in build' => {
+                type     => 'markdown',
+                filename => 'README.md',
+                location => 'build',
+                phase    => 'build',
+            },
+        ],
+
         qw(
             MojibakeTests
             PodSyntaxTests
+            Test::CleanNamespaces
             Test::CPAN::Changes
             Test::CPAN::Meta::JSON
             Test::EOL
@@ -427,6 +449,7 @@ sub _all_stopwords {
 
 sub _default_stopwords {
     return qw(
+        drolsky
         DROLSKY
         DROLSKY's
         PayPal
@@ -478,21 +501,53 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::PluginBundle::DROLSKY - DROLSKY's plugin bundle
 
 =head1 VERSION
 
-version 0.42
+version 0.43
+
+=head1 DESCRIPTION
+
+This is the L<Dist::Zilla> plugin bundle I use for my distributions. Don't use
+this directly for your own distributions, but you may find it useful as a
+source of ideas for building your own bundle.
 
 =for Pod::Coverage .*
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-PluginBundle-DROLSKY>
+(or L<bug-dist-zilla-pluginbundle-drolsky@rt.cpan.org|mailto:bug-dist-zilla-pluginbundle-drolsky@rt.cpan.org>).
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+
+=head1 DONATIONS
+
+If you'd like to thank me for the work I've done on this module, please
+consider making a "donation" to me via PayPal. I spend a lot of free time
+creating free software, and would appreciate any support you'd care to offer.
+
+Please note that B<I am not suggesting that you must do this> in order for me
+to continue working on this particular software. I will continue to do so,
+inasmuch as I have in the past, for as long as it interests me.
+
+Similarly, a donation made in this way will probably not make me work on this
+software much more, unless I get so many donations that I can consider working
+on free software full time (let's all have a chuckle at that together).
+
+To donate, log into PayPal and send money to autarch@urth.org, or use the
+button at L<http://www.urth.org/~autarch/fs-donation.html>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is Copyright (c) 2016 by Dave Rolsky.
 
